unit MyEE;
{$IFDEF FPC}
  {$MODE DELPHI}
  {$PACKRECORDS C}
  {$ALIGN 4}
  {$TYPEDADDRESS ON}
{$ENDIF}

{
    GALAXY ORGANIZER 32 bit.
    Version: 1.
    Written on FreePascal (https://freepascal.org/).
    Copyright (C) 1995-2025  Artyomov Alexander
    http://self-made-free.ru/
    aralni@mail.ru

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
}

interface
uses
  Windows, Messages, Dbg, MyForms, MyFButt, Algor, Common, SysUtils, MyConst, 
  MyCC, CDialogs, CommCtrl;

const
  ee_w = 550;
  ee_h = 380;
  ee_tv_w = 230;

const
  TVIF_PARAM = $0004;
  TVN_SELCHANGED = TVN_SELCHANGEDA;

type
  TMyTVItem = packed record
    mask: UINT;
    hItem: HTREEITEM;
    state: UINT;
    stateMask: UINT;
    pszText: LPSTR;
    cchTextMax: Integer;
    iImage: Integer;
    iSelectedImage: Integer;
    cChildren: Integer;
    lParam: LPARAM;
  end;

type
  MyEvEdit = class(TLiteWindow)
    hlistview, htreeview: THandle;
    ftab: Boolean;
    memkeysel: DWORD;
    ListView: TListView;
    vw: DWORD;
    
  protected
    procedure OnClose(var Msg: TMessage); message WM_CLOSE;
    procedure OnSize(var Msg: TWMSize); message WM_SIZE;
    procedure OnMove(var Msg: TWMMove); message WM_MOVE;
    procedure OnGMM(var Msg: TMessage); message WM_GETMINMAXINFO;
    procedure OnNotify(var Msg: TMessage); message WM_NOTIFY;
    procedure OnEUREKA(var Msg: TMessage); message WM_EUREKA;
    procedure OnDlt(var Msg: TMessage); message WM_DLT;
    procedure OnActivate(var Msg: TMessage); message WM_ACTIVATE;

    procedure SetTab(Value: Boolean);
    procedure WindowProcedure(var Msg: TMessage); override;
    
  public
    procedure Full; override;
    procedure AfterCreate; override;
    procedure Close;
    constructor Create(a: Word);
    procedure CPos;
    property Tab: Boolean read ftab write SetTab;
    procedure Act(w: Word);
    procedure SetView(w: Word);
    procedure SelectAll;
    procedure Delete;
    procedure ImpExp(fn: string; savetrue, rst: Boolean);
    procedure ImportAll;
    procedure ExportAll;
    procedure PlusFile;
    procedure ExportSel;
    procedure Info;
  end;

var
  EvEdit: MyEvEdit;
  eeev: MyEvent;

implementation
uses
  Application, MyDlgAl;

constructor MyEvEdit.Create;
begin
  efEE := true;
  vw := a;
  inherited Create(hDesktopWindow);
end;

procedure MyEvEdit.Full;
begin
  inherited;
  self.FLeft := app.stun.ee_left;
  self.FTop := app.stun.ee_top;
  self.FWidth := app.stun.ee_width;
  self.FHeight := app.stun.ee_height;
  self.Caption := ee_capt;
  self.FStyle := WS_SYSMENU or WS_MINIMIZEBOX or WS_MAXIMIZEBOX or WS_SIZEBOX;
  self.FExStyle := 0;
  self.WindowClassEx.hInstance := app.hinstance;
  WindowClassEx.hIcon := app.hi_calendar;
end;

procedure MyEvEdit.AfterCreate;
var
  ti: TVITEM;  // Используем стандартную структуру
  tis: TTVINSERTSTRUCT;
  m, f, ff: DWORD;
  hp, hItem: HTREEITEM;
  LC: TLVColumn;
begin
  if app.stun.ee_maximize then
    ShowWindow(hwnd, SW_SHOWMAXIMIZED)
  else
    ShowWindow(hwnd, SW_SHOWNORMAL);

  ListView := TListView.Create;
  hlistview := ListView.CrtTxtTbl(hwnd, app.hinstance, ee_tv_w + 1, 1, 100, 100);
  ListView_SetExtendedListViewStyle(ListView.hwnd, LVS_EX_GRIDLINES or LVS_EX_FULLROWSELECT);

  htreeview := TreeView.BaseCreate(hwnd, app.hinstance, 1, 1, ee_tv_w, 100);
  tab := true;

  lc.mask := LVCF_SUBITEM or LVCF_TEXT or LVCF_WIDTH;
  lc.fmt := 0;
  
  for f := 0 to editor_tab_name_max do 
  begin
    lc.pszText := PChar(editor_tab_name[f]);
    lc.cx := editor_tab_cx[f];
    lc.iSubItem := f;
    CommCtrl.ListView_InsertColumn(hlistview, f, lc);
  end;

  cpos;

  // Инициализация TreeView
  ZeroMemory(@ti, SizeOf(ti));
  ti.mask := TVIF_TEXT or TVIF_PARAM;
  tis.hParent := nil;
  tis.hInsertAfter := TVI_LAST;

  for m := 0 to editor_menu_root_max do 
  begin
    ZeroMemory(@ti, SizeOf(ti));
    ti.mask := TVIF_TEXT or TVIF_PARAM;
    ti.pszText := PChar(editor_menu_root[m]);
    ti.lParam := editor_menu_root_act[m];
    
    ZeroMemory(@tis, SizeOf(tis));
    tis.hParent := nil;
    tis.hInsertAfter := TVI_LAST;
    tis.item := ti;
    
    hp := TreeView_InsertItem(htreeview, @tis);
    tis.hParent := hp;

    case m of
      0: 
      begin
        for f := 0 to editor_view_root_max do 
        begin
          ZeroMemory(@ti, SizeOf(ti));
          ti.mask := TVIF_TEXT or TVIF_PARAM;
          ti.pszText := PChar(editor_view_root[f]);
          ti.lParam := editor_view_root_act[f];
          tis.item := ti;
          
          hItem := TreeView_InsertItem(htreeview, tis);
          
          case f of
            1: 
              for ff := 0 to period_max do 
              begin
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(period_name[ff]);
                ti.lParam := 200 + ff;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
              end;
            2: 
              for ff := 0 to action_max do 
              begin
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                if ff < 10 then 
                  ti.pszText := PChar(action_name1[ff])
                else 
                  ti.pszText := PChar(action_name[ff]);
                ti.lParam := 300 + ff;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
              end;
            3: 
              for ff := 0 to cat_max do 
              begin
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(cat_name[ff]);
                ti.lParam := 400 + ff;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
              end;
            4: 
              begin
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(alr_capt_del);
                ti.lParam := 500;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
                
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(alr_capt_diz);
                ti.lParam := 501;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
                
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(alr_capt_rtm);
                ti.lParam := 502;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
                
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(alr_capt_inf);
                LongInt(ti.lParam) := 503;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
                
                ZeroMemory(@ti, SizeOf(ti));
                ti.mask := TVIF_TEXT or TVIF_PARAM;
                ti.pszText := PChar(alr_capt_dsp);
                ti.lParam := 504;
                tis.item := ti;
                TreeView_InsertItem(htreeview, tis);
              end;
          end;
          tis.hParent := hp;
        end;
      end;
      1: 
        for f := 0 to editor_edit_max do 
        begin
          ZeroMemory(@ti, SizeOf(ti));
          ti.mask := TVIF_TEXT or TVIF_PARAM;
          ti.pszText := PChar(editor_edit[f]);
          ti.lParam := editor_edit_act[f];
          tis.item := ti;
          TreeView_InsertItem(htreeview, tis);
        end;
      2: 
        for f := 0 to editor_file_max do 
        begin
          ZeroMemory(@ti, SizeOf(ti));
          ti.mask := TVIF_TEXT or TVIF_PARAM;
          ti.pszText := PChar(editor_file[f]);
          ti.lParam := editor_file_act[f];
          tis.item := ti;
          TreeView_InsertItem(htreeview, tis);
        end;
    end;
    
    TreeView_Expand(htreeview, hp, TVE_EXPAND);
    tis.hParent := nil;
  end;

  SendMessage(hwnd, WM_EUREKA, 0, 0);
end;

procedure MyEvEdit.OnClose; begin close; end;
procedure MyEvEdit.Close; begin  efEE := false; destroy; end;

procedure MyEvEdit.OnSize;{WM_SIZE}
begin
 msg.Result := DefWindowProc(hwnd, msg.msg, TMessage(msg).WParam, TMessage(msg).LParam);
 cpos;
end;
procedure MyEvEdit.OnMove;{WM_MOVE}
begin
 msg.Result := DefWindowProc(hwnd, msg.msg, TMessage(msg).WParam, TMessage(msg).LParam);
 cpos;
end;

procedure MyEvEdit.CPos;
begin
 MemPosChange;
 app.stun.ee_maximize := isZoomed(hwnd);

if (not app.stun.ee_maximize) and (not isIconic(hwnd)) then begin
 app.stun.ee_width := FWidth;
 app.stun.ee_height := FHeight;
 app.stun.ee_top := FTop;
 app.stun.ee_left := FLeft;
end; {end if}

 SetWindowPos(hlistview, hlistview, 0, 0, FCWidth - ee_tv_w - 1, FCHeight - 1, SWP_NOACTIVATE or SWP_NOMOVE or SWP_NOZORDER);
 SetWindowPos(htreeview, htreeview, 0, 0, ee_tv_w, FCHeight - 1, SWP_NOACTIVATE or SWP_NOMOVE or SWP_NOZORDER);
end;

procedure MyEvEdit.OnGMM; {WM_GETMINMAXINFO}
  var
    p : PMINMAXINFO;
begin
p := Pointer(msg.LParam);
  p^.ptMinTrackSize.x := 400;
  p^.ptMinTrackSize.y := 250;
// msg.Result := DefWindowProc(hwnd, msg.msg, msg.WParam, Integer(p));
msg.Result := 0;
end;


{
procedure MyEvEdit.OnNotify(var Msg: TMessage);
var
  pnmhdr: ^TNMHDR;
  pnmtv: ^TNMTREEVIEW;
  tvItem: TTVITEM;
  hItem: HTREEITEM;
begin
  pnmhdr := Pointer(Msg.LParam);
  Msg.Result := DefWindowProc(hwnd, Msg.Msg, Msg.wParam, Msg.lParam);

  if pnmhdr^.hwndFrom = htreeview then
  begin
    case pnmhdr^.code of
      TVN_SELCHANGED:
      begin
        pnmtv := Pointer(Msg.LParam);
        hItem := TreeView_GetSelection(htreeview);
        
        FillChar(tvItem, SizeOf(tvItem), 0);
        tvItem.mask := TVIF_PARAM;
        tvItem.hItem := hItem;
        
        if TreeView_GetItem(htreeview, tvItem) then
        begin
          WriteLn('Real lParam = ', tvItem.lParam);
          act(Integer(tvItem.lParam));

WriteLn('SizeOf(TTVITEM): ', SizeOf(TTVITEM));
WriteLn('SizeOf(TNMTREEVIEW): ', SizeOf(TNMTREEVIEW));
        end
        else
          WriteLn('TreeView_GetItem failed: ', GetLastError);
      end;
    end;
  end;
end;
}

procedure MyEvEdit.OnNotify(var Msg: TMessage);
  var
//    pntv  : PNmTreeview;
    tlvi  : TLVHitTestInfo;
    l     : TLVItem;
    tmp   : longint;
  pnmhdr: ^TNMHDR;
//  pnmtv: ^TNMTREEVIEW;
  pnmtv: LPNMTREEVIEW;
  tvItem: TTVITEM;
  hItem: HTREEITEM;
begin
  pnmhdr := Pointer(Msg.LParam);
  Msg.Result := DefWindowProc(hwnd, Msg.Msg, Msg.wParam, Msg.lParam);

//  pntv := PNMTREEVIEW({Pointer(}TMessage(msg).LParam);

  if pnmhdr^.hwndFrom = htreeview then begin
    case pnmhdr^.code of
//     TVN_SELCHANGING: begin
TVN_SELCHANGED: begin
        pnmtv := Pointer(Msg.LParam);
      case pnmtv^.action of 
       TVC_BYMOUSE: begin

        hItem := TreeView_GetSelection(htreeview);
        
        FillChar(tvItem, SizeOf(tvItem), 0);
        tvItem.mask := TVIF_PARAM;
        tvItem.hItem := hItem;
        
        if TreeView_GetItem(htreeview, tvItem) then
        begin
//          WriteLn('Real lParam = ', tvItem.lParam);
          act(Integer(tvItem.lParam));
        end
        else
          WriteLn('TreeView_GetItem failed: ', GetLastError);

	PostMessage(htreeview, TVM_SELECTITEM, TVGN_CARET, Integer(0{hroot}));
	memkeysel := 0;
       end;
       TVC_BYKEYBOARD: begin
	memkeysel := pnmtv^.itemOld.lParam;
       end;
      end;
     end;
     NM_SETFOCUS: begin
	PostMessage(htreeview, TVM_SELECTITEM, TVGN_CARET, Integer(0{hroot}));
	ftab := false;
     end;
     NM_KILLFOCUS: begin
	ftab := true;
     end;
    end;
  end; {end if}

  if pnmhdr^.hwndFrom = hlistview then begin
    case pnmhdr^.code of
     LVN_COLUMNCLICK: begin
      // beep;
     end;
     NM_CLICK: begin
       if not(0 <> (GetAsyncKeyState(VK_CONTROL) and -32768)) then begin
       GetCursorPos(tlvi.pt);
       ScreenToClient(hlistview, tlvi.pt);
       commctrl.ListView_HitTest(hlistview, tlvi);
        if (tlvi.iItem > -1) then begin
        l.mask := LVIF_PARAM;
        l.iItem := tlvi.iItem;
        l.iSubItem := 0;
        if commctrl.ListView_GetItem(hlistview, l) then
         app.org.ShowAlarmDialog(app.org.w[l.lParam].number);
        end; {end if}
       end; {end if}
     end;
    end;
  end; {end if}
end;




procedure MyEvEdit.SetTab; begin ftab := value; if value then SetFocus(hlistview) else SetFocus(htreeview); end;

procedure MyEvEdit.Act;
begin
case w of
1: begin app.ShowHelp(2); PostMessage(hhelp, WM_ACTIVATE, WA_CLICKACTIVE, 0); end;
2: PostMessage(hwnd, WM_CLOSE, 0, 0);

100..2000 : begin SendMessage(hwnd, WM_EUREKA, w, 0);{vw := w; SetView(vw);} end;
2001: begin app.org.Add; PostMessage(halarmdialog, WM_ACTIVATE, WA_CLICKACTIVE, 0);
if efAld then PostMessage(alarmdlg.htype, WM_ACTIVATE, WA_CLICKACTIVE, 0);
end;
2002: delete;
2003: begin selectall; PostMessage(hlistview, WM_ACTIVATE, WA_CLICKACTIVE, 0); end;
3001: begin ExportAll; end;
3002: begin ExportSel; end;
3003: begin ImportAll; end;
3004: begin PlusFile; end;
3005: begin Info; end;
end; {end select}
end;

procedure MyEvEdit.WindowProcedure(var Msg : TMessage);
  var d : TDecodeKey; ctrl, shift : boolean;
      tmp   : longint; l : TLVItem;
begin
case msg.Msg of
     WM_KEYDOWN: begin
      d := DecodeKey(msg.WParam, msg.LParam);
       ctrl := GetAsyncKeyState(VK_CONTROL) = -32768;
       shift   := GetAsyncKeyState(VK_SHIFT)   = -32768;
  //    msg.result := 1;
      case d.virt of
       VK_RETURN : msg.result := 1;
       VK_ESCAPE : begin close; msg.Result := 1; end;
       9         : msg.result := 1;
       VK_DELETE : delete;
      else
          msg.result := 0;
      end; {end select}

     end;
     WM_KEYUP: begin
      d := DecodeKey(msg.WParam, msg.LParam);
       ctrl := GetAsyncKeyState(VK_CONTROL) = -32768;
       shift   := GetAsyncKeyState(VK_SHIFT)   = -32768;
//      msg.Result := 1;
      case d.virt of
           9    : begin tab := not tab; msg.Result := 1; end;
           65   : begin selectall; msg.Result := 1; end;
           VK_RETURN : if tab then begin
            tmp := ListView.GetFocusedItemIndex;
            if tmp > -1 then begin
            l := ListView.GetFocusedItem(tmp);
            app.org.ShowAlarmDialog(app.org.w[l.lParam].number);
                        end; {end if tmp>-1}
                                   end else begin
     act(memkeysel);
     PostMessage(htreeview, TVM_SELECTITEM, TVGN_CARET, Integer(0));
                                   end; {end if tab}
      else
          msg.result := 0;
      end; {end select d.virt}
     end; {ku}
else
    Dispatch(msg);
end; {end select msg.msg}
end;

procedure MyEvEdit.SetView;
  var     iii, f, ff : dword;
          s            : string;
begin ListView.Clear; iii := 0;
//                                  caption := inttostr(w);
for f := 1 to MAX_EVENT do begin
if not app.org.w[f].ex then continue;

case w of
101: if not app.org.w[f].ActivateInDay(app.stat.Mev) then continue;
102: if not app.org.w[f].ActivateInDay(app.stat.Mev.PlusDay) then continue;
103: if not app.org.w[f].ActivateInDay(eeev) then continue;
200..200 + period_max: if app.org.w[f].period <> (w - 200) then continue;
300..300 + action_max: if app.org.w[f].action <> (w - 300) then continue;
400..400 + cat_max: if app.org.w[f].cat <> (w - 400) then continue;
500: if not app.org.w[f].remove then continue;
501: if not app.org.w[f].disable then continue;
502: if not app.org.w[f].realtime then continue;
503: if not app.org.w[f].influence then continue;
504: if not app.org.w[f].display then continue;
end; {end select}

 for ff := 0 to editor_tab_name_max do begin
   case ff of
      0 : if app.org.w[f].disable then s := '[X] ' + app.org.w[f].mess else s := app.org.w[f].mess;
      1 : s := inttostr(app.org.w[f].year) + '/' + inttofix2str(app.org.w[f].month) + '/' + inttofix2str(app.org.w[f].day) + ' - ' + GetLocalHour(app.tun.engtrue_hour_fmt, app.org.w[f].hour) + ':' + inttofix2str(app.org.w[f].minute);
      2 : s := period_name[app.org.w[f].period];
      3 : s := inttostr(app.org.w[f].cycle);
      4 : s := inttostr(app.org.w[f].duration);
      5 : s := cat_name[app.org.w[f].cat];
      6 : if app.org.w[f].action > 9 then
          s := action_name[app.org.w[f].action]
          else s := action_name1[app.org.w[f].action];
      7 : s := app.org.w[f].filn;
      8 : s := str_tf[app.org.w[f].remove];
      9 : s := str_tf[app.org.w[f].disable];
     10 : s := str_tf[app.org.w[f].realtime];
     11 : s := str_tf[app.org.w[f].influence];
     12 : s := str_tf[app.org.w[f].display];
   end; {end select}
 ListView.TxtTblInsertItem(iii, ff, s, app.org.w[f].number);
 end; {next ff}
inc(iii); 
end; {next f}
end;

procedure MyEvEdit.OnEUREKA;
begin
  if msg.WParam > 0 then vw := msg.wparam;
  SetView(vw);
end;

procedure MyEvEdit.OnDlt;
  var
    f, lvcount : dword;
    l          : TLVItem;
begin
  lvcount := ListView.GetItemsCount;
 if lvcount > 0 then
  for f := 0 to lvcount - 1 do begin
    if ListView.isItemSelected(f) then begin
    l.mask := LVIF_PARAM;
    l.iItem := f;
    l.iSubItem := 0;
      if Boolean(SendMessage(hlistview, LVM_GETITEM, 0, Longint(@l))) then begin
        app.org.Delete(app.org.w[l.lParam].number);
      end; {end if}
    end; {end if}
  end; {next f}
  {Post}SendMessage(hwnd, WM_EUREKA, 0, 0);
  app.SetEventsCount;
     EnableWindow(hwnd, true);
end;
procedure MyEvEdit.Delete;
  var
    cnt : dword;
begin
    cnt := ListView.GetSelectedCount;
    if cnt > 0 then
    if MessageBox(hwnd, PCHar(ee_confirm_delete + inttostr(cnt)), PCHar(app_name), 52 or bit9) = idYes then begin
     //  SendMessage(hwnd, WM_DLT, 0, 0);
     app.fNeedDlt := true;
     EnableWindow(hwnd, false);
    end; {end if}
end;

procedure MyEvEdit.OnActivate;    {WM_ACTIVATE}
begin
   msg.Result := DefWindowProc(hwnd, msg.msg, msg.WParam, msg.LParam);
   if (LOWORD(msg.wparam) = WA_ACTIVE) or (LOWORD(msg.wparam) = WA_CLICKACTIVE) then
   SetFocus(hlistview);   
end;

procedure MyEvEdit.SelectAll;
begin
   ListView.SelectAll;
end;

procedure  MyEvEdit.ImpExp(fn : string; savetrue, rst : boolean);
begin
if app.fNeedExpImp then exit;
    app.fNeedExpImp  := true;
     app.f_resetorg  := rst;
     app.f_savetrue  := savetrue;
     app.f_ExpImpStr := fn;
end;

procedure MyEvEdit.ImportAll;
  var
    fd         : MyFileDlg;
begin if MessageBox(hwnd, editor_imp_quest, PCHar(app_name), bit6 or bit3 or bit5) <> ID_YES then exit;
if app.fNeedExpImp then exit;
fd := MyFileDlg.Create;
if not fd.GetFileName(hwnd, app.hinstance, 'Text Files (.TXT)'#0'*.txt'#0, 0, 'TXT', 'c:\', false, '') then exit;
ImpExp(fd.FileName, false, true);
end;
procedure MyEvEdit.ExportAll;
  var
    fd         : MyFileDlg;
begin if app.fNeedExpImp then exit;
if app.org.Count = 0 then exit;
fd := MyFileDlg.Create;
if not fd.GetFileName(hwnd, app.hinstance, 'Text Files (.TXT)'#0'*.txt'#0, 0, 'TXT', 'c:\', true, '') then exit;
ImpExp(fd.FileName, true, false);
end;
procedure MyEvEdit.PlusFile;
  var
    fd         : MyFileDlg;
begin if app.fNeedExpImp then exit;
fd := MyFileDlg.Create;
if not fd.GetFileName(hwnd, app.hinstance, 'Text Files (.TXT)'#0'*.txt'#0, 0, 'TXT', 'c:\', false, '') then exit;
ImpExp(fd.FileName, false, false);
end;
procedure MyEvEdit.ExportSel;
  var
    fd         : MyFileDlg;
begin if app.fNeedExpImp then exit;
if ListView.GetSelectedCount = 0 then exit;
fd := MyFileDlg.Create;
if not fd.GetFileName(hwnd, app.hinstance, 'Text Files (.TXT)'#0'*.txt'#0, 0, 'TXT', 'c:\', true, '') then exit;
ImpExp(fd.FileName, true, true);
end;

procedure MyEvEdit.Info;
begin
  MessageBox(hwnd,
  PCHar(
  editor_info_events +
  inttostr(app.org.Count) + #10#10 +
  book_info_file +
  wfn
  )
  , book_info_capt, bit7);
end;

initialization
   eeev.Reset;
finalization

end.



