unit inbx;

{
    GALAXY ORGANIZER 32 bit.
    Version: 1.
    Written on FreePascal (https://freepascal.org/).
    Copyright (C) 1995-2025  Artyomov Alexander
    http://self-made-free.ru/
    aralni@mail.ru

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
}

interface
           uses windows, messages, myforms, common, sysutils;

////////////////////////////////////////////////////////////////////////////////
//    
////////////////////////////////////////////////////////////////////////////////
type
  TDialogParams = record
    Template    : PChar;
    WndParent   : THandle;
  end;
////////////////////////////////////////////////////////////////////////////////
// TLiteDialogBox
// _____________________________________________________________________________
//   
////////////////////////////////////////////////////////////////////////////////
type
  TStrInputDialogBox = class(TLiteFrame)
    FDlgParams  : TDialogParams;
    fwantstr    : string;
    fcapt       : string;
    fokcapt     : string;
    fcancelcapt : string;
    fprompt     : string;
    fcas        : longint;
    flimittext  : longint;
  protected
    procedure   OnCommand(var Msg: TWMCommand); message WM_COMMAND;
    procedure   OnSysCommand(var Msg: TWMSysCommand); message WM_SYSCOMMAND;
    procedure   OnInitDialog(var Msg: TWMInitDialog); message WM_INITDIALOG;
  public
    procedure   DefaultHandler(var Msg); override;
    function    ShowModal: Integer;
  end;

function GetUserStrExecute(hwnd : THandle; capt, prompt, okcapt, canccapt : string; limitlen, ZeroNocaseOneUpTwoLo : longint; var wantstr : string) : boolean;

implementation

function GetUserStrExecute(hwnd : THandle; capt, prompt, okcapt, canccapt : string; limitlen, ZeroNocaseOneUpTwoLo : longint; var wantstr : string) : boolean;
  var
    f : TStrInputDialogBox;
begin
   f := TStrInputDialogBox.Create(hwnd);
    f.fwantstr := wantstr;    f.fcancelcapt := canccapt;
    f.fprompt := prompt;      f.fcas    := ZeroNocaseOneUpTwoLo;
    f.flimittext := limitlen; f.fcapt  := capt; f.fokcapt := okcapt;

   if f.ShowModal = idOk then begin
     wantstr := f.fwantstr;
     result := true;
   end else begin
     result := false;
   end; {end if}

    case f.fcas of
      1: wantstr := AUpperCase(wantstr);
      2: wantstr := ALowerCase(wantstr);
    end; {end select}
end;

////////////////////////////////////////////////////////////////////////////////
// TLiteDialogBox
// _____________________________________________________________________________
//  / 
////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
//   
////////////////////////////////////////////////////////////////////////////////
function TStrInputDialogBox.ShowModal : Integer;
begin
  //   
  FDlgParams.WndParent := HwndParent;
  FDlgParams.Template  := 'FILNAME';
  //  
  with FDlgParams do
    Result := DialogBoxParam(hInstance, Template, WndParent, WndCallback, 0);
end;

////////////////////////////////////////////////////////////////////////////////
//     
////////////////////////////////////////////////////////////////////////////////
procedure TStrInputDialogBox.DefaultHandler(var Msg);
begin
  //    
  with TMessage(Msg) do
    if Msg = WM_INITDIALOG then Result := 1
                           else Result := 0;
end;

////////////////////////////////////////////////////////////////////////////////
//    
////////////////////////////////////////////////////////////////////////////////
procedure TStrInputDialogBox.OnCommand(var Msg: TWMCommand);
  var
    p : Pointer;
    l : Longint;
begin
  //    "OK" -  
  if Msg.ItemID = 4 then
  begin
  l := GetWindowTextLength(GetDlgItem(hwnd, 3));
  if l > 0 then begin
    GetMem(p, l);
    GetDlgItemText(hwnd, 3, p, l + 1);
    fwantstr := String(PCHar(p));
  end else fwantstr := '';
    EndDialog(hwnd, IDOK);
    Msg.Result := 1;
  end;
  if Msg.ItemID = 5 then EndDialog(hwnd, IDCANCEL);
end;
////////////////////////////////////////////////////////////////////////////////
//  
////////////////////////////////////////////////////////////////////////////////
procedure TStrInputDialogBox.OnSysCommand(var Msg: TWMSysCommand);
begin
  //      ,   
  if Msg.CmdType = SC_CLOSE then
  begin
    EndDialog(hwnd, IDCANCEL);
    Msg.Result := 0;
    Exit;
  end;
  //     
  with TMessage(Msg) do
    DefWindowProc(hwnd, Msg, WParam, LParam);
end;

////////////////////////////////////////////////////////////////////////////////
//  
////////////////////////////////////////////////////////////////////////////////
procedure TStrInputDialogBox.OnInitDialog(var Msg: TWMInitDialog);
begin
  if fwantstr <> '' then SetDlgItemText(hwnd, 3, PCHar(fwantstr));
  SetDlgItemText(hwnd, 2, PCHar(fprompt));
  SetDlgItemText(hwnd, 5, PCHar(fcancelcapt));
  SetDlgItemText(hwnd, 4, PCHar(fokcapt));
  SendMessage(GetDlgItem(hwnd, 3), EM_LIMITTEXT, flimittext, 0);
  SetWindowText(hwnd, PCHar(fcapt));
  // 
  Msg.Result := 1;
end;

end.

