unit myrectrl;

{
    GALAXY ORGANIZER 32 bit.
    Version: 1.
    Written on FreePascal (https://freepascal.org/).
    Copyright (C) 1995-2025  Artyomov Alexander
    http://self-made-free.ru/
    aralni@mail.ru

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
}

interface

          uses windows, messages, sysutils, myforms, richedit, classes;

type
     TRichEdit = class(TObject)
     FWndParent   : THandle;
     FLeft        : Integer;
     FTop         : Integer;
     FWidth       : Integer;
     FHeight      : Integer;
     FStyle       : Longint;
     FExStyle     : Longint;
     FWndMenu     : THandle;
     protected
     private
     FHwnd        : THandle;
           procedure   SetText(const s : string);
           function    GetText : string;     
     public
           constructor Create(wndparent : THandle;
           AppInstance : THandle;
           Left, Top, Width, Height : integer;
           Style, ExStyle : longint;
           WndMenu : THandle
           );
           procedure   SetCanEdit(b : boolean);
           property    Hwnd : THandle read fHwnd;
           property    Text : string read GetText write SetText;
           procedure   MemPosChange;
           procedure   ApplyPosChange;
     end;

  var
      hLib : THandle;

implementation

constructor TRichEdit.Create;
begin inherited Create;
if hLib <> 0 then begin
FWndParent := wndparent;
FExStyle   := ExStyle;
FStyle     := Style;
FLeft      := Left;
FTop       := Top;
FWidth     := Width;
FHeight    := Height;
FWndMenu   := WndMenu;

FHwnd :=   CreateWindowEx(FExStyle, RICHEDIT_CLASS10A
           , '',  FStyle, FLeft, FTop, FWidth, FHeight,
           FWndParent, FWndMenu, AppInstance, nil    );

ApplyPosChange;

end else FHwnd := 0;
end;

////////////////////////////////////////////////////////////////////////////////
//     
//  ____________________
////////////////////////////////////////////////////////////////////////////////
procedure TRichEdit.MemPosChange;
var r : trect;
begin GetWindowRect(hwnd, r);
   FLeft     := r.Left;
   FTop      := r.Top;
   FWidth    := r.BottomRight.x - r.TopLeft.x;
   FHeight   := r.BottomRight.y - r.TopLeft.y;
{      GetClientRect(hwnd, r);
   FCHeight  := r.BottomRight.y - r.TopLeft.y;
   FCWidth   := r.BottomRight.x - r.TopLeft.x; }
end;
////////////////////////////////////////////////////////////////////////////////
//     
//  ____________________
////////////////////////////////////////////////////////////////////////////////
procedure TRichEdit.ApplyPosChange;
begin     SetWindowPos(FHwnd, FHwnd,
          FLeft, FTop, FWidth, FHeight,
          SWP_NOACTIVATE or SWP_NOZORDER);
end;

procedure   TRichEdit.SetText(const s : string);
begin SetWindowText(fHwnd, PCHar(s)); end;
function    TRichEdit.GetText : string;
  var
      p : Pointer;
      l : longint;
begin
      l := GetWindowTextLength(fHwnd);
      inc(l);
      GetMem(p, l);
        {do not use GetWindowText (it BUG !!!) WM_GETTEXT only !}
        if SendMessage(hwnd, WM_GETTEXT, l, Longint(p)) <> (l - 1) then MessageBox(hwnd, '(c) MS Windows: RichEdit Control Error', 'Error', MB_ICONSTOP or MB_OK);
      result := PCHar(p);
      FreeMem(p);
end;

procedure   TRichEdit.SetCanEdit(b : boolean);
begin
 if b then
 SendMessage(fHwnd, EM_SETOPTIONS, ECOOP_AND, not ECO_READONLY)
 else
 SendMessage(fHwnd, EM_SETOPTIONS, ECOOP_OR, ECO_READONLY);
end;

initialization

  hLib := LoadLibrary('RICHED32.DLL');

finalization

  if hLib <> 0  then FreeLibrary(hLib);

end.
